@@ -49,7 +49,7 @@ class FileBrowserSite(object):
         self.sort_by = self.order_by.strip('+-')
 
     def get_urls(self):
-        from django.conf.urls.defaults import patterns, url
+        from django.conf.urls import patterns, url
 
         urlpatterns = patterns(
             '',
